"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.balancedSpeed = void 0;
const helpers_1 = require("@wca/helpers");
const util_1 = require("./util");
const getPR = (person, eventId) => {
    var _a, _b, _c;
    const PRs = (_a = person.personalBests) === null || _a === void 0 ? void 0 : _a.filter((pb) => pb.eventId === eventId);
    const singlePr = PRs === null || PRs === void 0 ? void 0 : PRs.find((pb) => pb.type === 'single');
    if (['333bf', '444bf', '555bf', '333mbf'].includes(eventId)) {
        return (_b = singlePr === null || singlePr === void 0 ? void 0 : singlePr.best) !== null && _b !== void 0 ? _b : 0;
    }
    const averagePr = PRs === null || PRs === void 0 ? void 0 : PRs.find((pb) => pb.type === 'average');
    const result = (_c = averagePr === null || averagePr === void 0 ? void 0 : averagePr.best) !== null && _c !== void 0 ? _c : singlePr === null || singlePr === void 0 ? void 0 : singlePr.best;
    return result;
};
/**
 * Creates a constraint that ensures that group speeds stay balanced.
 * @param assignmentCode
 * @returns A number of people that are slower than the person
 */
exports.balancedSpeed = (0, util_1.createConstraint)('Balanced Speed', ({ wcif, activity, assignmentCode, person }) => {
    const { eventId } = (0, helpers_1.parseActivityCode)(activity.activityCode);
    const peopleInActivity = wcif.persons.filter((person) => {
        var _a;
        return (_a = person.assignments) === null || _a === void 0 ? void 0 : _a.some((assignment) => assignment.assignmentCode === assignmentCode &&
            assignment.activityId === activity.id);
    });
    const personPr = getPR(person, eventId);
    if (!personPr)
        return 0;
    const sumOfPRs = [...peopleInActivity].map((p) => {
        return getPR(p, eventId);
    });
    // Higher is better so we return negative numbers to prefer smaller groups.
    return -sumOfPRs.filter((pr) => (pr ? personPr < pr : true)).length;
});
//# sourceMappingURL=balancedSpeed.js.map