"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.maximizeBreaks = void 0;
const helpers_1 = require("@wca/helpers");
const util_1 = require("./util");
const activities_1 = require("../lib/activities");
/**
 * Creates a constraint that ensures that a person has their breaks maximized before the given assignment
 * @param eventId
 * @returns
 */
exports.maximizeBreaks = (0, util_1.createConstraint)('Maximize Breaks', ({ wcif, activity, activities, person }) => {
    // If no current assignments, don't apply constraint
    if (!(person === null || person === void 0 ? void 0 : person.assignments)) {
        return 0;
    }
    const allActivities = (0, activities_1.findAllActivities)(wcif);
    // Staff assignments are identified by the assignment code containing 'staff'
    const staffAssignmentsInActivities = person === null || person === void 0 ? void 0 : person.assignments.filter((assignment) => assignment.assignmentCode.includes('staff') &&
        activities.find((a) => a.id === assignment.activityId)).map((assignment) => {
        // Implication from the filter means that activity is not undefined
        const _activity = allActivities.find((a) => a.id === assignment.activityId);
        if (!_activity) {
            throw new Error(`[Maximize breaks] Activity ${assignment.activityId} not found`);
        }
        return Object.assign(Object.assign({}, assignment), { activity: _activity, groupNumber: (0, helpers_1.parseActivityCode)(_activity.activityCode).groupNumber });
    }).sort((a, b) => a.activity.startTime.localeCompare(b.activity.startTime));
    // If the person has no staff assignments in the activities, don't apply constraint
    // TODO: Make this work for all rounds rather than current
    if (!staffAssignmentsInActivities.length) {
        return 0;
    }
    // The activity we are weighing comes before this set of staff assignments
    if (activity.startTime < staffAssignmentsInActivities[0].activity.startTime) {
        const breakActivities = activities
            .filter((a) => a.endTime <= activity.startTime)
            .map((a) => a.startTime)
            .filter((a, i, arry) => arry.findIndex((b) => b === a) === i);
        return breakActivities.length;
    }
    // if not maximize the number of breaks before.
    const lastAssignment = staffAssignmentsInActivities[staffAssignmentsInActivities.length - 1];
    const breakActivities = activities
        .filter((a) => a.startTime >= lastAssignment.activity.endTime &&
        a.endTime <= activity.startTime)
        .map((a) => a.startTime)
        .filter((a, i, arry) => arry.findIndex((b) => b === a) === i);
    return breakActivities.length;
});
//# sourceMappingURL=maximizeBreaks.js.map