"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assignEveryone = void 0;
const helpers_1 = require("@wca/helpers");
const utils_1 = require("../utils");
const executeBalanced = ({ wcif, activities, assignmentCode, cluster, constraints, options, }) => {
    let tempPersons = wcif.persons;
    // Get actual unique group count for calcuations. In theory, the same group number is happening across the stages.
    const groupCount = new Set(activities.map((a) => a.activityCode)).size;
    const peoplePerGroup = cluster.length / groupCount;
    for (let i = 0; i < groupCount; i++) {
        const group = cluster.slice(i * peoplePerGroup, (i + 1) * peoplePerGroup);
        const groupActivities = activities.filter((activity) => {
            const { groupNumber } = (0, helpers_1.parseActivityCode)(activity.activityCode);
            return groupNumber === i + 1;
        });
        tempPersons = (0, utils_1.assignPersons)({
            cluster: group,
            wcif: Object.assign(Object.assign({}, wcif), { persons: tempPersons }),
            activities: groupActivities,
            assignmentCode,
            options,
            constraints,
        });
    }
    return Object.assign(Object.assign({}, wcif), { persons: tempPersons });
};
const executeSymmetric = ({ wcif, cluster, activities, assignmentCode, options, constraints, }) => (Object.assign(Object.assign({}, wcif), { persons: (0, utils_1.assignPersons)({
        cluster,
        wcif,
        activities,
        assignmentCode,
        options,
        constraints,
    }) }));
exports.assignEveryone = {
    name: 'Assign Everyone',
    description: 'Generates assignments such that everyone is assigned to one activity and one assignment code.',
    optionsDef: {
        mode: {
            name: 'Mode',
            type: 'select',
            description: 'How to assign people to activities',
            values: ['balanced', 'symmetric'],
            default: 'symmetric',
        },
    },
    defaultOptions: {
        mode: 'symmetric',
    },
    // everyone was given at least 1 assignment from the activities with the assignment code
    validate: ({ cluster, activities, assignmentCode, options }) => {
        const activityIds = activities.map((activity) => activity.id);
        return cluster.every((person) => {
            var _a;
            return (_a = person.assignments) === null || _a === void 0 ? void 0 : _a.some((assignment) => assignment.assignmentCode === assignmentCode &&
                activityIds.includes(assignment.activityId));
        });
    },
    execute: (props) => {
        switch (props.options.mode) {
            case 'symmetric':
                return executeSymmetric(props);
            case 'balanced':
                return executeBalanced(props);
            default:
                throw new Error(`Unknown mode ${props.options.mode}`);
        }
    },
};
//# sourceMappingURL=assignEveryone.js.map