"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assignXPerActivity = void 0;
exports.assignXPerActivity = {
    name: 'Assign X people per activity',
    description: 'Generates assignments such that each activity has x amount of people assigned to it with a given assignment code.',
    optionsDef: {
        x: {
            name: 'X',
            type: 'number',
            description: 'How many people to assign to each activity',
            min: 1,
            default: 1,
        },
    },
    defaultOptions: {
        x: 1,
    },
    // everyone was given at least 1 assignment from the activities with the assignment code
    validate: ({ cluster, activities, options }) => {
        const activityIds = activities.map((activity) => activity.id);
        return activityIds.every((activityId) => cluster.filter((person) => {
            var _a;
            return (_a = person.assignments) === null || _a === void 0 ? void 0 : _a.some((assignment) => assignment.assignmentCode === options.assignmentCode &&
                assignment.activityId === activityId);
        }));
    },
    execute: ({ wcif, cluster, activities, options }) => {
        if (cluster.length < activities.length * options.x) {
            throw new Error(`Not enough people to assign ${options.x} people to each activity`);
        }
        // Score people and pick the most qualified person for the activity;
        // TODO
        activities.forEach((activity) => {
            for (let i = 0; i < options.x; i++) { }
        });
        return Object.assign({}, wcif);
    },
};
//# sourceMappingURL=assignXPerActivity.js.map