"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findPR = exports.byResult = exports.byPsychsheet = exports.byPROrResult = void 0;
const helpers_1 = require("@wca/helpers");
/**
 * "Scores" People's results or PRs and sorts differently depending on roundNumber.
 * People's scores
 * @param {Event} event
 * @param {ActivityCode} roundId
 * @param {Result[]} roundResults
 * @returns
 */
const byPROrResult = (event, roundNumber) => (personA, personB) => {
    var _a, _b;
    if (roundNumber === 1) {
        return (0, exports.byPsychsheet)(event.id)(personA, personB);
    }
    // previousRound *will* be defined because we're not in round 1
    const previousRound = (_a = event.rounds) === null || _a === void 0 ? void 0 : _a.find((r) => (0, helpers_1.parseActivityCode)(r.id).roundNumber === roundNumber - 1);
    if (!((_b = previousRound.results) === null || _b === void 0 ? void 0 : _b.length)) {
        return 0;
    }
    return (0, exports.byResult)(previousRound.results)(personA, personB);
};
exports.byPROrResult = byPROrResult;
/**
 * Comparator for array.sort
 * TODO: cleanup
 */
const byPsychsheet = (eventId) => (a, b) => {
    var _a, _b;
    if (!a.wcaId && b.wcaId) {
        return 1;
    }
    else if (a.wcaId && !b.wcaId) {
        return -1;
    }
    else if (!a.wcaId && !b.wcaId) {
        return a.name.localeCompare(b.name);
    }
    const aPRs = ((_a = a.personalBests) === null || _a === void 0 ? void 0 : _a.filter((pr) => pr.eventId === eventId)) || [];
    const bPRs = ((_b = b.personalBests) === null || _b === void 0 ? void 0 : _b.filter((pr) => pr.eventId === eventId)) || [];
    if (!(aPRs === null || aPRs === void 0 ? void 0 : aPRs.length) && (bPRs === null || bPRs === void 0 ? void 0 : bPRs.length)) {
        return 1;
    }
    else if ((aPRs === null || aPRs === void 0 ? void 0 : aPRs.length) && !(bPRs === null || bPRs === void 0 ? void 0 : bPRs.length)) {
        return -1;
    }
    else if (!(aPRs === null || aPRs === void 0 ? void 0 : aPRs.length) && !(bPRs === null || bPRs === void 0 ? void 0 : bPRs.length)) {
        return 0;
    }
    const aSingle = (0, exports.findPR)(aPRs, eventId, 'single');
    const bSingle = (0, exports.findPR)(bPRs, eventId, 'single');
    // If we get here, we know that both competitors have a single
    if (['333bf', '444bf', '555bf', '333mbf'].includes(eventId)) {
        return aSingle.worldRanking - bSingle.worldRanking;
    }
    const aAverage = (0, exports.findPR)(aPRs, eventId, 'average');
    const bAverage = (0, exports.findPR)(bPRs, eventId, 'average');
    if (!aAverage && bAverage) {
        return 1;
    }
    else if (aAverage && !bAverage) {
        return -1;
    }
    else if (aAverage && bAverage && aAverage !== bAverage) {
        return aAverage.worldRanking - bAverage.worldRanking;
    }
    // This is the tie breaker for averages
    // If we get here, we know that both competitors have a single
    return aSingle.worldRanking - bSingle.worldRanking;
};
exports.byPsychsheet = byPsychsheet;
/**
 * Comparator for array.sort
 * Sorts people by their ranking in the round
 * @param {*} results
 * @returns
 */
const byResult = (results) => (a, b) => {
    var _a, _b;
    const aResult = ((_a = results.find((r) => r.personId === a.registrantId)) === null || _a === void 0 ? void 0 : _a.ranking) ||
        Number.MAX_SAFE_INTEGER;
    const bResult = ((_b = results.find((r) => r.personId === b.registrantId)) === null || _b === void 0 ? void 0 : _b.ranking) ||
        Number.MAX_SAFE_INTEGER;
    return aResult - bResult;
};
exports.byResult = byResult;
const findPR = (personalBests, eventId, type) => personalBests.find((pr) => pr.eventId === eventId && pr.type === type);
exports.findPR = findPR;
//# sourceMappingURL=persons.js.map